.. toctree::
   :caption: Getting Started
   :hidden:

   Introduction <self>
   Install jobflow <install>
   Tutorials <tutorials>

.. toctree::
   :caption: User Interface
   :hidden:

   Job <job>
   Flow <flow>
   Maker <maker>

.. toctree::
   :caption: Information
   :hidden:

   changelog
   contributors
   contributing
   license
   jobflow on GitHub <https://github.com/hackingmaterials/jobflow>


.. toctree::
   :caption: Function Reference
   :maxdepth: -1
   :hidden:

   API reference <jobflow>
   genindex

============
Introduction
============

.. mdinclude:: ../../README.md
   :start-line: 5
